@@ -70,19 +70,25 @@ func TestStatusManager_set(t *testing.T) {
 		t.Fatalf("unexpected error (expected Not Found): %v", err)
 	}
 
+	condUpdate := configv1.ClusterOperatorStatusCondition{
+		Type:   configv1.OperatorUpgradeable,
+		Status: configv1.ConditionTrue,
+	}
+
 	condFail := configv1.ClusterOperatorStatusCondition{
 		Type:    configv1.OperatorDegraded,
 		Status:  configv1.ConditionTrue,
 		Reason:  "Reason",
 		Message: "Message",
 	}
-	status.Set(false, condFail)
+	status.set(false, condFail)
 
 	co, err = getCO(client, "testing")
 	if err != nil {
 		t.Fatalf("error getting ClusterOperator: %v", err)
 	}
-	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condFail}) {
+
+	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condFail, condUpdate}) {
 		t.Fatalf("unexpected Status.Conditions: %#v", co.Status.Conditions)
 	}
 
@@ -90,13 +96,13 @@ func TestStatusManager_set(t *testing.T) {
 		Type:   configv1.OperatorProgressing,
 		Status: configv1.ConditionUnknown,
 	}
-	status.Set(false, condProgress)
+	status.set(false, condProgress)
 
 	co, err = getCO(client, "testing")
 	if err != nil {
 		t.Fatalf("error getting ClusterOperator: %v", err)
 	}
-	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condFail, condProgress}) {
+	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condFail, condUpdate, condProgress}) {
 		t.Fatalf("unexpected Status.Conditions: %#v", co.Status.Conditions)
 	}
 
@@ -104,13 +110,13 @@ func TestStatusManager_set(t *testing.T) {
 		Type:   configv1.OperatorDegraded,
 		Status: configv1.ConditionFalse,
 	}
-	status.Set(false, condNoFail)
+	status.set(false, condNoFail)
 
 	co, err = getCO(client, "testing")
 	if err != nil {
 		t.Fatalf("error getting ClusterOperator: %v", err)
 	}
-	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condNoFail, condProgress}) {
+	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condNoFail, condUpdate, condProgress}) {
 		t.Fatalf("unexpected Status.Conditions: %#v", co.Status.Conditions)
 	}
 
@@ -122,13 +128,13 @@ func TestStatusManager_set(t *testing.T) {
 		Type:   configv1.OperatorAvailable,
 		Status: configv1.ConditionTrue,
 	}
-	status.Set(false, condNoProgress, condAvailable)
+	status.set(false, condNoProgress, condAvailable)
 
 	co, err = getCO(client, "testing")
 	if err != nil {
 		t.Fatalf("error getting ClusterOperator: %v", err)
 	}
-	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condNoFail, condNoProgress, condAvailable}) {
+	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condNoFail, condUpdate, condNoProgress, condAvailable}) {
 		t.Fatalf("unexpected Status.Conditions: %#v", co.Status.Conditions)
 	}
 }
@@ -142,6 +148,10 @@ func TestStatusManagerSetDegraded(t *testing.T) {
 		t.Fatalf("unexpected error (expected Not Found): %v", err)
 	}
 
+	condUpdate := configv1.ClusterOperatorStatusCondition{
+		Type:   configv1.OperatorUpgradeable,
+		Status: configv1.ConditionTrue,
+	}
 	condFailCluster := configv1.ClusterOperatorStatusCondition{
 		Type:   configv1.OperatorDegraded,
 		Status: configv1.ConditionTrue,
@@ -164,7 +174,7 @@ func TestStatusManagerSetDegraded(t *testing.T) {
 	if err != nil {
 		t.Fatalf("error getting ClusterOperator: %v", err)
 	}
-	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condFailOperator}) {
+	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condFailOperator, condUpdate}) {
 		t.Fatalf("unexpected Status.Conditions: %#v", co.Status.Conditions)
 	}
 
@@ -174,7 +184,7 @@ func TestStatusManagerSetDegraded(t *testing.T) {
 	if err != nil {
 		t.Fatalf("error getting ClusterOperator: %v", err)
 	}
-	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condFailCluster}) {
+	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condFailCluster, condUpdate}) {
 		t.Fatalf("unexpected Status.Conditions: %#v", co.Status.Conditions)
 	}
 
@@ -184,7 +194,7 @@ func TestStatusManagerSetDegraded(t *testing.T) {
 	if err != nil {
 		t.Fatalf("error getting ClusterOperator: %v", err)
 	}
-	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condFailCluster}) {
+	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condFailCluster, condUpdate}) {
 		t.Fatalf("unexpected Status.Conditions: %#v", co.Status.Conditions)
 	}
 
@@ -194,7 +204,7 @@ func TestStatusManagerSetDegraded(t *testing.T) {
 	if err != nil {
 		t.Fatalf("error getting ClusterOperator: %v", err)
 	}
-	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condFailCluster}) {
+	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condFailCluster, condUpdate}) {
 		t.Fatalf("unexpected Status.Conditions: %#v", co.Status.Conditions)
 	}
 
@@ -204,7 +214,7 @@ func TestStatusManagerSetDegraded(t *testing.T) {
 	if err != nil {
 		t.Fatalf("error getting ClusterOperator: %v", err)
 	}
-	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condFailPods}) {
+	if !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condFailPods, condUpdate}) {
 		t.Fatalf("unexpected Status.Conditions: %#v", co.Status.Conditions)
 	}
 
@@ -214,7 +224,7 @@ func TestStatusManagerSetDegraded(t *testing.T) {
 	if err != nil {
 		t.Fatalf("error getting ClusterOperator: %v", err)
 	}
-	if !v1helpers.IsStatusConditionFalse(co.Status.Conditions, configv1.OperatorDegraded) {
+	if !v1helpers.IsStatusConditionFalse(co.Status.Conditions, configv1.OperatorDegraded) && !conditionsEqual(co.Status.Conditions, []configv1.ClusterOperatorStatusCondition{condUpdate}) {
 		t.Fatalf("unexpected Status.Conditions: %#v", co.Status.Conditions)
 	}
 }
@@ -271,6 +281,10 @@ func TestStatusManagerSetFromDaemonSets(t *testing.T) {
 			Status: configv1.ConditionTrue,
 			Reason: "Deploying",
 		},
+		{
+			Type:   configv1.OperatorUpgradeable,
+			Status: configv1.ConditionTrue,
+		},
 		{
 			Type:   configv1.OperatorAvailable,
 			Status: configv1.ConditionFalse,
@@ -318,6 +332,10 @@ func TestStatusManagerSetFromDaemonSets(t *testing.T) {
 				Type:   configv1.OperatorProgressing,
 				Status: configv1.ConditionTrue,
 			},
+			{
+				Type:   configv1.OperatorUpgradeable,
+				Status: configv1.ConditionTrue,
+			},
 			{
 				Type:   configv1.OperatorAvailable,
 				Status: configv1.ConditionFalse,
@@ -375,6 +393,10 @@ func TestStatusManagerSetFromDaemonSets(t *testing.T) {
 			Type:   configv1.OperatorProgressing,
 			Status: configv1.ConditionFalse,
 		},
+		{
+			Type:   configv1.OperatorUpgradeable,
+			Status: configv1.ConditionTrue,
+		},
 		{
 			Type:   configv1.OperatorAvailable,
 			Status: configv1.ConditionTrue,
@@ -467,6 +489,10 @@ func TestStatusManagerSetFromPods(t *testing.T) {
 			Status: configv1.ConditionTrue,
 			Reason: "Deploying",
 		},
+		{
+			Type:   configv1.OperatorUpgradeable,
+			Status: configv1.ConditionTrue,
+		},
 		{
 			Type:   configv1.OperatorAvailable,
 			Status: configv1.ConditionFalse,
@@ -498,6 +524,10 @@ func TestStatusManagerSetFromPods(t *testing.T) {
 			Type:   configv1.OperatorProgressing,
 			Status: configv1.ConditionFalse,
 		},
+		{
+			Type:   configv1.OperatorUpgradeable,
+			Status: configv1.ConditionTrue,
+		},
 		{
 			Type:   configv1.OperatorAvailable,
 			Status: configv1.ConditionTrue,
@@ -544,6 +574,10 @@ func TestStatusManagerSetFromPods(t *testing.T) {
 			Type:   configv1.OperatorProgressing,
 			Status: configv1.ConditionTrue,
 		},
+		{
+			Type:   configv1.OperatorUpgradeable,
+			Status: configv1.ConditionTrue,
+		},
 		{
 			Type:   configv1.OperatorAvailable,
 			Status: configv1.ConditionTrue,
@@ -573,6 +607,10 @@ func TestStatusManagerSetFromPods(t *testing.T) {
 			Type:   configv1.OperatorProgressing,
 			Status: configv1.ConditionFalse,
 		},
+		{
+			Type:   configv1.OperatorUpgradeable,
+			Status: configv1.ConditionTrue,
+		},
 		{
 			Type:   configv1.OperatorAvailable,
 			Status: configv1.ConditionTrue,
